export default class {
    protected db: any;
    protected appKey: string;
    protected token: string;
    constructor(db: any, appKey: string, token: string);
    run(): Promise<any>;
    protected process(data: any): Promise<any>;
    protected processOrg(org: any): Promise<any>;
    protected processBoard(board: any): Promise<any>;
    protected processLabels(labels: any): Promise<any>;
    protected processLists(lists: any): Promise<any>;
    protected processCards(cards: any): Promise<any>;
    protected processMembers(members: any): Promise<any>;
    protected getBoards(): Promise<any[]>;
    api(url: string, options?: object): Promise<any>;
    get(url: any, options?: object): Promise<any>;
}
